@@ -609,4 +609,56 @@ def get_kpi(price_df, default_metrics = [simple_return, annual_return, annual_vo
         i += 1
 
     kpis_df = pd.DataFrame(results, columns=price_df.columns, index=[m.__name__ for m in default_metrics])
-    return kpis_df
\ No newline at end of file
+    return kpis_df
+
+def compute_extensive_kpis(data_df = None, strat = None):
+    btd_kpis = get_kpi(data_df[[strat]])
+    data_df['year'] = data_df.index.year
+    data_df['month'] = data_df.index.year.astype(str) + '_' + data_df.index.month.astype(str)
+    def compute_metrics(df, strat=None):
+        kpi_df = get_kpi(df[[strat]])
+        return kpi_df.to_dict()[strat]
+
+    go_comp_kpi = lambda x: compute_metrics(x, strat=strat)
+    monthepochkpis_df = data_df[['month', strat]].groupby(['month']).apply(go_comp_kpi)
+    monthepochkpis_df = pd.DataFrame.from_records(monthepochkpis_df.to_dict()).T
+    monthepochkpis_df = monthepochkpis_df.dropna()
+    ratio_positive_month = (monthepochkpis_df['simple_return']>=0.).sum()/len(monthepochkpis_df)
+
+    yearepochkpis_df = data_df[['year', strat]].groupby(['year']).apply(go_comp_kpi)
+    yearepochkpis_df = pd.DataFrame.from_records(yearepochkpis_df.to_dict()).T
+    yearepochkpis_df = yearepochkpis_df.dropna()
+    ratio_positive_year = (yearepochkpis_df['simple_return']>=0.).sum()/len(yearepochkpis_df)
+
+    print('done')
+    data_df = data_df.sort_index()
+    current_values = data_df.iloc[-1]
+    current_date = data_df.index[-1]
+    current_year = str(current_date.year-1)
+
+    ytd_date = pd.Timestamp(f'{current_year}-12-31')
+    ytd_values = data_df.loc[ytd_date]
+
+    ytd_ohlc_df = data_df.loc[ytd_date:].copy()
+
+    ytd_kpis = riskmetrics.get_kpi(ytd_ohlc_df[[strat]])
+
+    return_ytd_to_date = (current_values['close'] - ytd_values['close'])/ytd_values['close']
+    results = {}
+    results[f'return_ytd'] = return_ytd_to_date
+
+    for nb_month in [1,3,6]:
+        back_date = data_df.index[-1] + pd.DateOffset(months=-1*nb_month)
+
+        past_values = data_df.loc[back_date]
+        return_to_date = (current_values['close'] - past_values['close'])/past_values['close']
+        results[f'return_{nb_month}_month'] = return_to_date
+
+    past_returns = pd.Series(results)
+
+    ### 1 month return
+    btd_kpis_dict = btd_kpis.to_dict()[strat]
+    btd_kpis_dict['ratio_positive_month']=ratio_positive_month
+    btd_kpis_dict['ratio_positive_year'] =ratio_positive_year
+    btd_kpis_dict_df = pd.Series(btd_kpis_dict)
+    return btd_kpis_dict_df, ytd_kpis, past_returns
